@@ -18,6 +18,7 @@
 
 import enum
 import os
+from pathlib import Path
 import shutil
 import tempfile
 from util import delete_tempfile
@@ -98,6 +99,8 @@ class QemuCommand:
         assert(variant is None or variant in QemuEfiVariant)
         assert(flash_size in QemuEfiFlashSize)
 
+        root = Path(os.environ.get('DEB_EDK2_ROOT', '/'))
+
         code_ext = '.no-secboot' if machine == QemuEfiMachine.AAVMF else ''
         vars_ext = ''
         if variant == QemuEfiVariant.MS:
@@ -117,29 +120,29 @@ class QemuCommand:
         if machine == QemuEfiMachine.AAVMF:
             assert(flash_size == QemuEfiFlashSize.DEFAULT)
             return (
-                f'/usr/share/AAVMF/AAVMF_CODE{code_ext}.fd',
-                f'/usr/share/AAVMF/AAVMF_VARS{vars_ext}.fd',
+                root / f'usr/share/AAVMF/AAVMF_CODE{code_ext}.fd',
+                root / f'usr/share/AAVMF/AAVMF_VARS{vars_ext}.fd'
             )
         if machine == QemuEfiMachine.AAVMF32:
             assert(variant is None)
             assert(flash_size == QemuEfiFlashSize.DEFAULT)
             return (
-                '/usr/share/AAVMF/AAVMF32_CODE.fd',
-                '/usr/share/AAVMF/AAVMF32_VARS.fd'
+                root / 'usr/share/AAVMF/AAVMF32_CODE.fd',
+                root / 'usr/share/AAVMF/AAVMF32_VARS.fd'
             )
         if machine == QemuEfiMachine.LOONGARCH64:
             assert(variant is None)
             assert(flash_size == QemuEfiFlashSize.DEFAULT)
             return (
-                '/usr/share/qemu-efi-loongarch64/QEMU_EFI.fd',
-                '/usr/share/qemu-efi-loongarch64/QEMU_VARS.fd',
+                root / 'usr/share/qemu-efi-loongarch64/QEMU_EFI.fd',
+                root / 'usr/share/qemu-efi-loongarch64/QEMU_VARS.fd'
             )
         if machine == QemuEfiMachine.RISCV64:
             assert(variant is None)
             assert(flash_size == QemuEfiFlashSize.DEFAULT)
-            return (
-                '/usr/share/qemu-efi-riscv64/RISCV_VIRT_CODE.fd',
-                '/usr/share/qemu-efi-riscv64/RISCV_VIRT_VARS.fd',
+            return(
+                root / 'usr/share/qemu-efi-riscv64/RISCV_VIRT_CODE.fd',
+                root / 'usr/share/qemu-efi-riscv64/RISCV_VIRT_VARS.fd',
             )
         # Remaining possibilities are OVMF variants
         assert(
@@ -157,8 +160,8 @@ class QemuCommand:
         else:
             OVMF_ARCH = "OVMF"
         return (
-            f'/usr/share/OVMF/{OVMF_ARCH}_CODE{size_ext}{code_ext}.fd',
-            f'/usr/share/OVMF/{OVMF_ARCH}_VARS{size_ext}{vars_ext}.fd'
+            root / f'usr/share/OVMF/{OVMF_ARCH}_CODE{size_ext}{code_ext}.fd',
+            root / f'usr/share/OVMF/{OVMF_ARCH}_VARS{size_ext}{vars_ext}.fd',
         )
 
     def __init__(
